# A: Select a working directory
setwd("C:/...")


# B: Write the integrated population model in JAGS language

sink("IPM-shrike.jags")
cat("
##########################################################################
#  Age structured model (2 age classes: 1-year old vs. 2-years old or older)
#  Age at first breeding = 1 year
#  Pre-breeding census
#  All vital rates are assumed to be time-dependent
#  Immigration is included additively in the model as a number
##########################################################################

model
{

############################################################
# 1. Define the priors for the parameters
############################################################ 

    # Initial population sizes
    rf ~ dnorm(10, 0.01)T(0,)
    Rf[1] <- round(rf)      # Local recruits (females)
    sf ~ dnorm(15, 0.01)T(0,)
    Sf[1] <- round(sf)      # Surviving adults (females)
    ifem ~ dnorm(25, 0.01)T(0,)
    If[1] <- round(ifem)    # Immigrants (females)

    rm ~ dnorm(10, 0.01)T(0,)
    Rm[1] <- round(rm)      # Local recruits (males)
    sm ~ dnorm(15, 0.01)T(0,)
    Sm[1] <- round(sm)      # Surviving adults (males)
    imale ~ dnorm(25, 0.01)T(0,)
    Im[1] <- round(imale)   # Immigrants (males)

    # Relationship for vital rates parameters
    for (t in 1:(ti-1)){
    	logit(phijf[t]) <- logit.b0.phijf + epsilon[t,1]
    	logit(phiaf[t]) <- logit.b0.phiaf + epsilon[t,2]
    	logit(phijm[t]) <- logit.b0.phijm + epsilon[t,3]
    	logit(phiam[t]) <- logit.b0.phiam + epsilon[t,4]
    	log(fec[t]) <- log.b0.fec + epsilon[t,5]
    	log(omegaf[t]) <- log.b0.omf + epsilon[t,6]
    	log(omegam[t]) <- log.b0.omm + epsilon[t,7]
    	logit(pjf[t]) <- logit.b0.pjf + err.pjf[t]
    	logit(pf[t]) <- logit.b0.pf + err.pf[t]
    	logit(pjm[t]) <- logit.b0.pjm + err.pjm[t]
    	logit(pm[t]) <- logit.b0.pm + err.pm[t]
    	}

    # Priors for random effects of demographic rates
    for (i in 1:7) {zero[i] <- 0}
    for (t in 1:(ti-1)){
    	epsilon[t,1:7]  ~ dmnorm(zero[], Omega[,])
    	}
    
    # Prior for precision matrix
    Omega[1:7, 1:7]  ~ dwish(R[ , ], 8)
    Sigma[1:7, 1:7] <- inverse(Omega[ , ])

    # Priors for random effects of resighting rates
    for (t in 1:(ti-1)){
    	err.pjf[t] ~ dnorm(0, tau.pjf)
    	err.pf[t] ~ dnorm(0, tau.pf)
    	err.pjm[t] ~ dnorm(0, tau.pjm)
    	err.pm[t] ~ dnorm(0, tau.pm)
    	}
    
   # Priors for variance parameters (hyperparameters) of resighting rates and census error
	tau.pjf <- 1 / pow(sigma.pjf, 2)
	sigma.pjf ~ dunif(0, 10)
	sigma2.pjf <- pow(sigma.pjf, 2)
	
	tau.pf <- 1 / pow(sigma.pf, 2)
	sigma.pf ~ dunif(0, 10)
	sigma2.pf <- pow(sigma.pf, 2)
	
	tau.pjm <- 1 / pow(sigma.pjm, 2)
	sigma.pjm ~ dunif(0, 10)
	sigma2.pjm <- pow(sigma.pjm, 2)
	
	tau.pm <- 1 / pow(sigma.pm, 2)
	sigma.pm ~ dunif(0, 10)
	sigma2.pm <- pow(sigma.pm, 2)   

	tau.c ~ dgamma(0.001, 0.001)
	sigma2.c <- 1 / tau.c
   
   # Priors for the mean of demographic and resighting rates
	b0.phijf ~ dunif(0, 1)
	b0.phiaf ~ dunif(0, 1)
	b0.phijm ~ dunif(0, 1)
	b0.phiam ~ dunif(0, 1)
	b0.fec ~ dunif(0, 10)
	b0.omf ~ dunif(0, 75)
	b0.omm ~ dunif(0, 75)
	b0.pjf ~ dunif(0, 1)
	b0.pf ~ dunif(0, 1)
	b0.pjm ~ dunif(0, 1)
	b0.pm ~ dunif(0, 1)
	
   # Back-transformations	
	logit.b0.phijf <- log(b0.phijf / (1 - b0.phijf))
	logit.b0.phiaf <- log(b0.phiaf / (1 - b0.phiaf))
	logit.b0.phijm <- log(b0.phijm / (1 - b0.phijm))
	logit.b0.phiam <- log(b0.phiam / (1 - b0.phiam))
	log.b0.fec <- log(b0.fec)
	log.b0.omf <- log(b0.omf)
	log.b0.omm <- log(b0.omm)
	logit.b0.pjf <- log(b0.pjf / (1 - b0.pjf))
	logit.b0.pf <- log(b0.pf / (1 - b0.pf))
	logit.b0.pjm <- log(b0.pjm / (1 - b0.pjm))
	logit.b0.pm <- log(b0.pm / (1 - b0.pm))

    # Prior for productivity in the last year
    fec[ti] ~ dunif(0, 10)   # treated as fixed effect (not possible to be included in the random effects)
    

###################################################################
# 2. Derived parameters
###################################################################

    for (t in 1:(ti-1)){
        iratef[t] <- If[t+1] / Bf[t]     # Immigration rate of females
        iratem[t] <- Im[t+1] / Bm[t]     # Immigration rate of males
        }

######################################################################
# 3. Likelihoods of the integrated population model
######################################################################
	
   ####################################################
   # 3.1 Likelihood for reproductive data
   ####################################################

     for (t in 1:ti){
       J[t] ~ dpois(rho[t])
       rho[t] <- M[t] * fec[t]
       } #i

   ####################################################
   # 3.2 Likelihood for population survey data
   ####################################################

       #############################
       # 3.2.1 System process
       #############################

       for (t in 2:ti){
          meanfl[t-1] <- fec[t-1] * Bf[t-1]
          F[t-1] ~ dpois(meanfl[t-1])          # Total number of fledglings
          Ff[t-1] ~ dbin(0.5, F[t-1])          # Number of female fledglings
          Rf[t] ~ dbin(phijf[t-1], Ff[t-1])    # Number of female local recruits
          Sf[t] ~ dbin(phiaf[t-1], Bf[t-1])    # Number of surviving adult females
          If[t] ~ dpois(omegaf[t-1])           # Number of immigrated females
          
          Fm[t-1] <- F[t-1] - Ff[t-1]          # Number of male fledglings
          Rm[t] ~ dbin(phijm[t-1], Fm[t-1])    # Number of male local recruits
          Sm[t] ~ dbin(phiam[t-1], Bm[t-1])    # Number of surviving adult males
          Im[t] ~ dpois(omegam[t-1])           # Number of immigrated males
          } # t

          # Number of fledglings in the last study year
          meanfl[ti] <- fec[ti] * Bf[ti]
          F[ti] ~ dpois(meanfl[ti])
          Ff[ti] ~ dbin(0.5, F[ti])
          Fm[ti] <- F[ti] - Ff[ti]


       ###############################
       # 3.2.2 Observation process
       ###############################

       for(t in 1:ti){
          Bf[t] <- Sf[t] + Rf[t] + If[t]       # Total number of breeding females
          logBf[t] <- log(Bf[t])
          Cf[t] ~ dlnorm(logBf[t], tau.c)
         
          Bm[t] <- Sm[t] + Rm[t] + Im[t]       # Total number of breeding males
          logBm[t] <- log(Bm[t])
          Cm[t] ~ dlnorm(logBm[t], tau.c)         
          } # t

   ################################################
   # 3.3 Likelihood for capture-recapture data (Cormack-Jolly-Seber model with 2 age classes)
   ################################################
     
   # Likelihhod
   for (t in 1:2*(ti-1)){
       MF[t,1:ti] ~ dmulti(prf[t,], r.f[t])
       MM[t,1:ti] ~ dmulti(prm[t,], r.m[t])
       } # t

   # m-array cell probabilities for juveniles
   for (t in 1:(ti-1)){
       qf[t] <- 1-pf[t]		# probability of non-capture (females)
       qm[t] <- 1-pm[t]		# probability of non-capture (males)
       # main diagonal
       prf[t,t] <- phijf[t] * pjf[t]
       prm[t,t] <- phijm[t] * pjm[t]

       # above main diagonal
       for (j in (t+1):(ti-1)){
           prf[t,j] <- phijf[t] * prod(phiaf[(t+1):j]) * (1-pjf[t]) * prod(qf[t:(j-1)]) * pf[j] / qf[t]
           prm[t,j] <- phijm[t] * prod(phiam[(t+1):j]) * (1-pjm[t]) * prod(qm[t:(j-1)]) * pm[j] / qm[t]
           } # j

       # below main diagonal
       for (j in 1:(t-1)){
           prf[t,j] <- 0
           prm[t,j] <- 0
          } # j

       # last column
       prf[t,ti] <- 1 - sum(prf[t,1:(ti-1)])
       prm[t,ti] <- 1 - sum(prm[t,1:(ti-1)])
       } # t

   # m-array cell probabilities for adults
   for (t in 1:(ti-1)){
       # main diagonal
       prf[t+ti-1,t] <- phiaf[t] * pf[t]
       prm[t+ti-1,t] <- phiam[t] * pm[t]

       # above main diagonal
       for (j in (t+1):(ti-1)){
           prf[t+ti-1,j] <- prod(phiaf[t:j]) * prod(qf[t:(j-1)]) * pf[j]
           prm[t+ti-1,j] <- prod(phiam[t:j]) * prod(qm[t:(j-1)]) * pm[j]
           } # j

       # below main diagonal
       for (j in 1:(t-1)){
           prf[t+ti-1,j] <- 0
           prm[t+ti-1,j] <- 0
           } # j

       # last column
       prf[t+ti-1,ti] <- 1 - sum(prf[t+ti-1,1:(ti-1)])
       prm[t+ti-1,ti] <- 1 - sum(prm[t+ti-1,1:(ti-1)])
       } # t  

}  # End Model
",fill = TRUE)
sink()

############################################################################


# C: The red-backed shrike data (1971-2006)

# Population survey:
BP <- c(47, 62, 62, 64, 72, 74, 68, 65, 38, 45, 35, 35, 39, 41, 39, 41, 40, 50, 56, 49, 45, 47, 63, 59, 61, 71, 61, 55, 58, 48, 44, 43, 50, 67, 68, 62)
	
# Reproductive success:	
J <- c(112, 114, 88, 167, 108, 223, 171, 127, 102, 84, 94, 104, 108, 102, 103, 92, 124, 132, 203, 133, 118, 155, 193, 135, 158, 121, 139, 134, 158, 120, 76, 111, 196, 218, 191, 162)
M <- c(29, 46, 50, 56, 65, 62, 63, 60, 33, 41, 35, 33, 38, 40, 38, 36, 36, 47, 54, 43, 44, 48, 59, 60, 59, 66, 61, 53, 57, 45, 42, 35, 45, 60, 56, 52)

# Capture-recapture data in m-array format:
# Females
MF <- matrix(c(2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,
0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,
0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,
0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,
0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,
0,0,0,0,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,
0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,
0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,
0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,
0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,
0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,70,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,1,0,0,0,0,0,0,0,0,0,0,78,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,91,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,77,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,78,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,58,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,0,0,0,0,0,0,0,71,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,4,1,0,0,0,0,0,69,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,94,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,66,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,39,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,69,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,94,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,117,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,105,
6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,
0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,
0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,
0,0,0,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,
0,0,0,0,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,
0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,
0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,
0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,
0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,
0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,
0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,
0,0,0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,
0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,
0,0,0,0,0,0,0,0,0,0,0,0,0,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,28,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,0,0,0,0,0,0,0,0,0,0,0,0,24,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,1,0,0,1,0,0,0,0,0,0,0,0,35,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,23,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,29,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,0,0,30,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,28,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,1,0,0,0,0,0,13,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,30,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,1,0,0,0,24,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,19,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,25,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,0,17,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,32,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,24), ncol = 36, byrow = T)

# Males
MM <- matrix(c(3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,
0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,
0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,
0,0,0,7,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,
0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,
0,0,0,0,0,8,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,
0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,
0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,
0,0,0,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,
0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,
0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,
0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,
0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,
0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,73,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,65,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,2,0,1,0,0,0,0,0,0,0,0,0,0,75,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,1,0,0,0,0,0,0,0,0,0,0,95,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,3,0,1,0,0,0,0,0,0,0,0,71,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,1,0,0,0,0,0,0,0,0,76,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,64,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,1,0,0,0,0,0,0,71,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,2,0,0,0,0,0,76,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,0,0,0,0,0,91,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,61,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,41,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,67,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,6,0,87,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,1,118,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,115,
19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,
0,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,
0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,
0,0,0,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,
0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,
0,0,0,0,0,31,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,
0,0,0,0,0,0,27,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,
0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,
0,0,0,0,0,0,0,0,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,
0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,
0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,
0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,
0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,
0,0,0,0,0,0,0,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,1,0,0,0,0,0,0,0,0,0,0,0,0,34,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,1,1,0,0,0,0,0,0,0,0,0,0,0,17,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,1,0,0,0,0,0,0,0,0,0,0,35,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,32,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,5,0,0,0,0,0,0,0,0,0,34,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,0,0,0,0,0,0,46,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,32,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,43,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,0,0,0,36,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,0,0,0,0,35,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,31,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,30,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,18,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,38,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42), ncol = 36, byrow = T)



shrike.data <- list(ti = ncol(MF), MF = MF, MM = MM, r.f = rowSums(MF), r.m = rowSums(MM), Cf = BP[1:ncol(MF)], Cm = BP[1:ncol(MF)], J = J[1:ncol(MF)], M = M[1:ncol(MF)], R = diag(c(1,1,1,1,1,1,1), ncol = 7)) 

################################################################


# D: Run the model in JAGS from R (requires package R2jags):

# Load required package 
library(R2jags)

# MCMC settings
chain <- 3
burn <- 500000
iter <- 1000000
thin <- 100

# Specify initial values
ti <- ncol(MF)
inits <- function() {list(b0.phijf = runif(1,0,0.5), b0.phiaf = runif(1,0.1,0.6), b0.phijm = runif(1,0,0.5), b0.phiam = runif(1,0.1,0.6), b0.fec = runif(1,2,3), b0.omf = runif(1,0,20), b0.omm = runif(1,0,20), b0.pjf = runif(1,0.2,0.7), b0.pf = runif(1,0.1,0.6), b0.pjm = runif(1,0.2,0.7), b0.pm = runif(1,0.5,1), sigma.pjf = runif(1,0,1), sigma.pf = runif(1,0,1), sigma.pjm = runif(1,0,1), sigma.pm = runif(1,0,1), If = c(NA, round(runif(ti-1,0,20),0)), Im = c(NA, round(runif(ti-1,0,20),0)), Omega = diag(7))}  

# Define parameters to be monitored
parameters <- c("phijf", "phiaf", "b0.phijf", "b0.phiaf", "phijm", "phiam", "b0.phijm", "b0.phiam", "b0.fec", "b0.omf", "b0.omm", "b0.pjf", "b0.pf", "b0.pjm", "b0.pm", "Sigma", "sigma2.pjf", "sigma2.pf", "sigma2.pjm", "sigma2.pm", "Rf", "Sf", "Bf", "If", "Rm", "Sm", "Bm", "Im", "fec", "iratef", "iratem", "pf", "pjf", "pm", "pjm", "sigma2.c", "F", "Ff", "Fm")

# Run the model
shrike.model <- jags(shrike.data, inits = inits, model.file = "IPM-shrike.jags", parameters = parameters, n.chains = chain, n.iter = iter, n.burnin = burn, n.thin = thin, working.directory = getwd())
